@@ -1,5 +1,4 @@
-from django_netjsonconfig.utils import get_controller_urls
-
+from ..utils import get_controller_urls
 from . import views
 
 app_name = 'openwisp_controller'
